# An example of showing the difference of interpreting artificial FRET efficiencies using SAW-nu and Gaussian chain model
# Both SAW-nu and Gaussian chain functions are included in 'solve_fret.py'

# SAW-nu citation
# Zheng W, Zerze G, Borgia A, Mittal J, Schuler B and Best RB. 
# J. Chem. Phys. 148:123329 (2018)

import numpy as np
import scipy.optimize as op
import solve_fret as fret

# R0 of FRET dye; dye and solvent dependent.
r0=5.4
# We find 0.55 nm good for a well-mixed IDP sequence.
prefactor=0.55
r=np.arange(0.0,29,0.1)

# FRET efficiency as examples
E=np.arange(0.1,1.0,0.1)
# Number of peptide bonds = chain length - 1
N=99

# input
# E: FRET efficiency; N: number of peptide bonds
# r0: R0 of FRET dye; prefactor: 0.55 nm good for a well-mixed IDP sequence.
# r: distance vector for integration
# output
# d2saw: squared distance from SAW-nu
# nusaw: polymer scaling exponent from SAW-nu
d2saw,nusaw=fret.d2_saw(E,N,r0,r,prefactor)

# Gaussian chain model for comparison
d2gau=fret.d2_gaussian(E,r0,r)
ratio=fret.ratio(nusaw)

print('FRET efficiency; distance-SAW-nu (nm); nu; alpha; distance-Gaussian (nm)')
for i in range(len(E)):
	print('%5.3f  %5.3f  %5.3f   %5.3f   %5.3f'%(E[i],np.sqrt(d2saw[i]),nusaw[i],ratio[i],np.sqrt(d2gau[i])))
